Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(964)

Unified Diff: media/formats/webm/webm_audio_client.h

Issue 1786733004: Revert of media config: expand is_encrypted to a struct. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/formats/mpeg/mpeg_audio_stream_parser_base.cc ('k') | media/formats/webm/webm_audio_client.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/formats/webm/webm_audio_client.h
diff --git a/media/formats/webm/webm_audio_client.h b/media/formats/webm/webm_audio_client.h
index 06d7e0c6caa769e0be31de065069902eee310518..fefa55ff2f947aa900ada18941cc39257d89ac5a 100644
--- a/media/formats/webm/webm_audio_client.h
+++ b/media/formats/webm/webm_audio_client.h
@@ -16,7 +16,6 @@
namespace media {
class AudioDecoderConfig;
-class EncryptionScheme;
// Helper class used to parse an Audio element inside a TrackEntry element.
class WebMAudioClient : public WebMParserClient {
@@ -28,8 +27,8 @@
void Reset();
// Initialize |config| with the data in |codec_id|, |codec_private|,
// |encryption_scheme| and the fields parsed from the last audio track element
// this object was used to parse.
// Returns true if |config| was successfully initialized.
// Returns false if there was unexpected values in the provided parameters or
// audio track element fields.
@@ -37,7 +36,7 @@
const std::vector<uint8_t>& codec_private,
const int64_t seek_preroll,
const int64_t codec_delay,
- const EncryptionScheme& encryption_scheme,
+ bool is_encrypted,
AudioDecoderConfig* config);
private:
« no previous file with comments | « media/formats/mpeg/mpeg_audio_stream_parser_base.cc ('k') | media/formats/webm/webm_audio_client.cc » ('j') | no next file with comments »
@@ -28,8 +27,8 @@
void Reset();
// Initialize |config| with the data in |codec_id|, |codec_private|,
- // |encryption_scheme| and the fields parsed from the last audio track element
- // this object was used to parse.
+ // |is_encrypted| and the fields parsed from the last audio track element this
+ // object was used to parse.
// Returns true if |config| was successfully initialized.
// Returns false if there was unexpected values in the provided parameters or

Powered by Google App Engine
This is Rietveld 408576698